/************************************************/
/* PURPOSE:       Verifies existence of specified datasets in parameter list (DATALST) before
/*                allowing downstream processing.    
/*                Ends the SAS program if a dataset does not exist.     
/* INPUT:         DATALST: Space-delimited list of SAS dataset names	  
/* OUTPUT:  	  NA
/* MACROS USED:   NA
/* AUTHOR:          
/* CREATION DATE:
/* EXAMPLES:      Example 1: Verify existence of a specified list of data sets. 
/*                           %dataexst(perm.status perm.visits perm.f0010) 
/*
/*               
/*                Example 2:  DATALST contains a set of variables that resolve to a list 
/*                            of datasets.
/*                            From availibility.sas:
/*                            %dataexst(&STATUS %if %length(&TRTFILE) %then &TRTFILE;)
/*    
/* NOTES:         PARAMETER: DATALST (required): A list of sas datasets separated by blank.
/*    
/************************************************/

    
%macro dataexst(DATALST);
   %local i DSN MISSING;

   %do i=1 %to %sysfunc(countw(&DATALST));
      %let dsn=%scan(&DATALST,&i,%str( ));
      %if %sysfunc(exist(&DSN))=0 %then
         %let missing=%cmpres(&MISSING &DSN);
   %end;
   %if %length(&MISSING) %then %do;

   %put %upcase(error): Dataset(s) %upcase(&MISSING) do not exist.; 

   endsas;
   %end;

%mend;

 
