/******************************************************************************/
/* PURPOSE:       To standardize yes/no macro  parameters as either Y/N/<null> or 
/*                YES/NO/<null>
/* 
/* INPUT:         Argument 1:  A list of the names of macro variables to be
/*                             standardized (space-delimited)
/*                Argument 2:  Optional YES value will standardize macro var
/*                             values to YES/NO/<null> instead of Y/N
/* OUTPUT:        The input macro variables with standardized values
/* 
/* NOTES:         
/*                Do not use & when specifying input macro variable names.            
/*                Examples:
/*                      %yesnosub(bytrt)
/*                      %yesnosub(bytrt totalcol suppct)
/*                      %yesnosub(bytrt totalcol suppct, YES)
/******************************************************************************/
%macro yesnosub(PARMLIST,LONGTEXT);

%local i EACHPARM YESVAL NOVAL;

%if %length(&&&PARMLIST) %then %do;

   /* setting result values to short (Y,N) or long (YES,NO)  */
   %if %upcase(&LONGTEXT) = YES %then %do;
      %let YESVAL = YES;
      %let NOVAL = NO;
   %end;
   %else %do;
      %let YESVAL = Y;
      %let NOVAL = N;
   %end;

   /* do once for each parameter listed in PARMLIST  */
   %let i = 1;
   %do %while( %length(%scan(&PARMLIST,&i)) > 0 );
      %let EACHPARM = %scan(&PARMLIST,&i);

      /* check that value is ( Y or YES) or ( N or NO )  so missed commas will be caught  */
      %if %length(&&&EACHPARM) %then %do;
         %if %upcase(%str(&&&EACHPARM)) = %str(Y) or %upcase(%str(&&&EACHPARM)) = %str(YES) %then 
            %let &EACHPARM = &YESVAL;
         %else %if %upcase(%str(&&&EACHPARM)) = %str(N) or %upcase(%str(&&&EACHPARM)) = %str(NO) %then 
            %let &EACHPARM = &NOVAL;
         %else %do;
            %let &EACHPARM = %str();
            %put %upcase(warning):  Invalid value for parameter &EACHPARM.  Null value will be used.;
         %end;
      %end;

      %let i = %eval(&i + 1);
   %end;

%end;
%else %put %upcase(warning): No input given to macro %nrstr(%YESNOSUB).;

%mend;
